@@ -5,9 +5,10 @@ try:
     from django.core.management import call_command
     from django.conf import settings
     from django.test.simple  import DjangoTestSuiteRunner
+    from django.core import mail
     try:
         from south.management.commands import patch_for_test_db_setup
-        USE_SOUTH = True
+        USE_SOUTH = getattr(settings, "SOUTH_TESTS_MIGRATE", False)
     except:
         USE_SOUTH = False
 
@@ -45,5 +46,11 @@ try:
         logger.info("Flushing...")
         call_command('flush', interactive=False, verbosity=0)
 
+    @before.each_feature
+    def empty_outbox(scenario):
+        logger.info("Emptying outbox...")
+        mail.outbox = []
+
+
 except:
     logger.warn("Django terrains not imported.")
